{% extends "layout.html" %}
{% block body %}
        <div class="main">
          <ul class="breadcrumb" style="margin-bottom: 5px;">
            <li><a href="{{ url_for('home') }}">Home</a></li>
            <li class="active">Live monitor</li>
          </ul>
          <div class="row" id="live-container">
          </div>
        </div>
{% endblock %}
