{% extends "layout.html" %}
{% block body %}
        {% include "notifications.html" %}
        <div class="col-sm-9 col-sm-offset-3 col-md-10 col-md-offset-2 main">
          {% include "small_topbar.html" %}
          <ul class="breadcrumb" style="margin-bottom: 5px;">                      
            <li><a href="{{ url_for('home') }}">Home</a></li>                      
            <li class="active">{{ cname }} overview</li>
          </ul>                                                                    
          <br />
          <h1 class="page-header">{{ cname }}</h1>

          <h2 class="sub-header">Backups</h2>
          <div class="table-responsive">
            <table class="table table-striped table-hover" id="table-client">
              <thead>
                <tr>
                  <th>Number</th>
                  <th>Date</th>
                </tr>
              </thead>
              <tbody>
              </tbody>
            </table>
            <div class="alert alert-dismissable alert-danger" id="client-alert" style="display: none;">
              <span class="glyphicon glyphicon-exclamation-sign"></span> <strong>Sorry!</strong> There are no backups for this client.
            </div>
          </div>
        </div>
{% endblock %}
