        <div {% if not login %}class="col-sm-9 col-sm-offset-3 col-md-10 col-md-offset-2"{% endif %}>
          <div id="bui-notifications">
            {% with messages = get_flashed_messages(with_categories=true) -%}
              {% if messages -%}
                {% for category, message in messages -%}
                  <div class="alert alert-dismissable alert-{{category}}">
                    <button type="button" class="close" data-dismiss="alert">×</button>
                    {{message}}
                  </div>
                {% endfor -%}
              {% endif -%}
            {% endwith -%}
          </div>
        </div>
