    <div class="navbar navbar-inverse navbar-fixed-top" role="navigation">
      <div class="container-fluid">
        <div class="navbar-header">
          <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-collapse">
            <span class="sr-only">Toggle navigation</span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </button>
          <a class="navbar-brand" href="{{ url_for('home') }}">Burp Server Dashboard</a>
        </div>
        <div class="navbar-collapse collapse">
          <ul class="nav navbar-nav navbar-right">
            <li class="detail{% if clients %} active{% endif %}"><a href="{{ url_for('home') }}"><span class="glyphicon glyphicon-home"></span><span class="dtl" style="display:none;">&nbsp;Clients</span></a></li>
            <li class="detail disabled"><a href="#"><span class="glyphicon glyphicon-wrench"></span><span class="dtl" style="display:none;">&nbsp;Settings</span></a></li>
            <li class="detail{% if live %} active{% endif %}"><a href="{{ url_for('live_monitor') }}"><span id="toblink" class="glyphicon glyphicon-screenshot"></span><span class="dtl" style="display:none;">&nbsp;Live monitor</span></a></li>
            {% if current_user and current_user.is_authenticated() %}
            <li class="detail"><a href="{{ url_for('logout') }}"><span class="glyphicon glyphicon-log-out"></span><span class="dtl" style="display:none;">&nbsp;Logout <small>({{ current_user.name }})</small></span></a></li>
            {% endif %}
            <li><a id="refresh" href="#"><span class="glyphicon glyphicon-refresh"></span></a></li>
          </ul>
          <form class="navbar-form navbar-right" id="search">
            <input type="text" class="form-control" id="input-client" placeholder="Search client..." autocomplete="off">
          </form>
        </div>
      </div>
    </div>
