<br />
<div class="col-lg-12">
  <h1 class="page-header">{{ cname }}</h1>
  <h4>{{ (counters.bytes_in / counters.estimated_bytes * 100)|round }}%</h4>
  <div class="progress progress-striped active">
    <div class="progress-bar progress-bar-success" style="width: {{ counters.bytes_in / counters.estimated_bytes * 100 }}%"></div>
  </div>
  {% if counters.path %}
  <div class="panel panel-primary">
    <div class="panel-heading">
      <h3 class="panel-title">Path</h3>
    </div>
    <div class="panel-body">
      {{ counters.path }}
    </div>
  </div>
  {% endif %}
  <div class="row">
    <div class="col-lg-6">
      <ul class="list-group">
        <li class="list-group-item">
          <span class="badge">{{ counters.phase }}</span>
          Phase
        </li>
        <li class="list-group-item">
          <span class="badge">{{ counters.timeleft|time_human }}</span>
          Time left
        </li>
        {% if counters.warning > 0 %}
        <li class="list-group-item">
          <span class="badge">{{ counters.warning }}</span>
          Warning
        </li>
        {% endif %}
      </ul>
    </div>
    <div class="col-lg-6">
      <ul class="list-group">
        <li class="list-group-item">
          <span class="badge">{{ counters.bytes_in|bytes_human }}</span>
          Bytes received
        </li>
        <li class="list-group-item">
          <span class="badge">{{ counters.speed|bytes_human }}/s</span>
          Speed
        </li>
      </ul>
    </div>
  </div>
  <table class="table table-striped table-hover" id="table-stats">
    <thead>
      <tr>
        <th></th>
        <th>New</th>
        <th>Changed</th>
        <th>Unchanged</th>
        <th>Deleted</th>
        <th>Scanned</th>
      </tr>
    </thead>
    <tbody>
    {% for d in counters %}
    {% if isinstance(counters[d], list) and d != 'Grand total' %}
      <tr>
        <th>{{ d }}</th>
        {% for v in counters[d] %}
        <td>{{ v }}</th>
        {% endfor %}
      </tr>
    {% endif %}
    {% endfor %}
    </tbody>
  </table>
</div>
