          <div class="btn-group btn-group-justified  hidden-md hidden-lg">
            {% if backup %}
            <a class="btn btn-default {% if overview %}active{% endif %}" href="{{ url_for('client_browse', name=cname) }}?backup={{ nbackup }}">Overview</a>
            {% elif client %}
            <a class="btn btn-default {% if overview %}active{% endif %}" href="{{ url_for('client', name=cname) }}">Overview</a>
            {% elif clients %}
            <a class="btn btn-default {% if overview %}active{% endif %}" href="{{ url_for('home') }}">Overview</a>
            {% else %}
            <a class="btn btn-default {% if overview %}active{% endif %}" href="#">Overview</a>
            {% endif %}
            {% if client and not backup %}
            <a class="btn btn-default {% if report %}active{% endif %}" href="{{ url_for('client_report', name=cname) }}">Reports</a>
            {% elif clients %}
            <a class="btn btn-default {% if report %}active{% endif %}" href="{{ url_for('clients_report') }}">Reports</a>
            {% elif backup %}
            <a class="btn btn-default {% if report %}active{% endif %}" href="{{ url_for('backup_report', name=cname, backup=nbackup) }}">Reports</a>
            {% else %}
            <a class="btn btn-default {% if report %}active{% endif %}" href="#">Reports</a>
            {% endif %}
          </div>
          <br />
