<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="description" content="">
    <meta name="author" content="">

    <title>Burp Server Dashboard</title>

    <!-- Bootstrap core CSS -->
    <link href="{{ url_for('static', filename='bootstrap/bootstrap.min.css') }}" rel="stylesheet">
    {% if report %}
    <link href="{{ url_for('static', filename='nvd3/nv.d3.min.css') }}" rel="stylesheet">
    {% endif %}
    {% if tree %}
    <link href="{{ url_for('static', filename='fancytree/skin-bootstrap/ui.fancytree.css') }}" rel="stylesheet">
    {% endif %}

    <!-- Custom styles for this template -->
    <link href="{{ url_for('static', filename='dashboard.css') }}" rel="stylesheet">

  </head>

  <body>

    {% include "topbar.html" %}

    <div class="container-fluid">
      <div class="row">
        {% if not live and not login %}
        {% include "sidebar.html" %}
        {% endif %}
        {% block body %}{% endblock %}
      </div>
    </div>

    <!-- Bootstrap core JavaScript
    ================================================== -->
    <!-- Placed at the end of the document so the pages load faster -->
    <script src="{{ url_for('static', filename='jquery/jquery.min.js') }}"></script>
    <script src="{{ url_for('static', filename='bootstrap/bootstrap.min.js') }}"></script>
    <!-- Typeadhead + Bloodhound Javascript
    ================================================== -->
    <script src="{{ url_for('static', filename='typeahead/typeahead.jquery.min.js') }}"></script>
    <script src="{{ url_for('static', filename='typeahead/bloodhound.min.js') }}"></script>
    {% if report %}
    <!-- d3 + nvd3 Javascript
    ================================================== -->
    <script src="{{ url_for('static', filename='d3/d3.min.js') }}"></script>
    <script src="{{ url_for('static', filename='nvd3/nv.d3.min.js') }}"></script>
    {% endif %}
    {% if tree %}
    <!-- Fancytree Javascript
    ================================================== -->
    <script src="{{ url_for('static', filename='jquery-ui/jquery-ui-1.10.4.min.js') }}"></script>
    <script src="{{ url_for('static', filename='fancytree/jquery.fancytree-custom.min.js') }}"></script>
    <script src="{{ url_for('static', filename='fancytree/jquery.fancytree.filter.js') }}"></script>
    {% endif %}
    <script type="text/javascript">
      {% include "gerard.js" %}
    </script>
  </body>
</html>

